<?php
$page_title = "Potential Duplicate Accounts";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					
				</div>
				<form id="searchForm" action="" method="post">
					<table class="conditions fontS w100p">
						<colgroup>
							<col class="w40p">
							<col class="w60p">
						</colgroup>
						<tr>
							<td style="font-weight:bold">Email Address&nbsp;</th>
							<td><?php $this -> echoMail(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">Account Number:&nbsp;</th>
							<td><?php $this -> echoAccountNumber(); ?></td>
						</tr>
						<tr>
							<td style="font-weight:bold">Name:&nbsp;</th>
							<td><?php $this -> echoName(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">Date of Birth:&nbsp;</th>
							<td><?php $this -> echoBirth(); ?></td>
						</tr>
						<tr>
							<td style="font-weight:bold">Review Status:&nbsp;</th>
							<td><?php $this -> echoAccountStatus(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">Address:&nbsp;</th>
							<td><?php $this -> echoAddress(); ?></td>
						</tr>				
						<tr>
							<th style="font-weight:bold">Date of Account Opening</th>
							<td><?php $this -> echoCreateTime(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">IP Address</th>
							<td><?php $this -> echoIPAddress(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">Country</th>
							<td><?php $this -> echoCountry(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">References:&nbsp;</th>
							<td><?php $this -> echoCount(); ?></td>
						</tr>
					</table>
					<input type="hidden" value="search" id="type_search" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<?php $this -> dispPager(); ?>
						</div>
						<?php // $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th class="w10p">Email Address</th>
									<th class="w5p">Account Number</th>
									<th class="w5p">Name</th>
									<th class="w5p">Date of Birth</th>
									<th class="w5p">Review Status</th>
									<!-- <th class="w5p">Country</th> -->
									<th class="w10p">Address</th>
									<th class="w10p">IP Address</th>
									<th class="w10p">Country</th>
									<th class="w10p">Reason</th>
									<!-- <th class="w5p">Date of Account of Opening</th> -->
									<!-- <th class="w5p">Date of Account Closing</th> -->
									<th class="w3p">Threshold</th>
									<th class="w3p">Delete</th>
								</tr>
								<?php /* $this -> echoList(); */ ?>
								<?php $this -> echoJson() ?>
							</table>
							<!-- <div style="display: flex; justify-content: flex-end; margin-bottom:-25px">
							<p>Account Number:  <input type="text"> <input type="button" id="btnAdd" value="Add" class="btn bg-default px50 hi22"> </p>
							</div> -->
							<input type="hidden" value="account_edit" id="action" name="action" />
							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" id="detail_account" name="detail_account" />
							<input type="hidden" id="user_account" name="user_account" value="<?php $this -> echoAccountNumber(); ?>" />
							<input type="hidden" id="child_account" name="child_account" />
						</form>
						<div class="article-bottom">
							<?php  $this -> dispPager(); ?>
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/account_list.js"></script>
</body>
</html>
